@@ -285,7 +285,9 @@ class DirectMessage(BaseModel):
     reactions: Optional[dict]
     text: Optional[str]
     link: Optional[dict]
+    animated_media: Optional[dict]
     media: Optional[DirectMedia]
+    visual_media: Optional[dict]
     media_share: Optional[Media]
     reel_share: Optional[dict]
     story_share: Optional[dict]
